@@ -36,48 +36,34 @@ G_BEGIN_DECLS
 #define GPM_NAME 			_("Power Manager")
 #define GPM_DESCRIPTION 		_("Power Manager for the GNOME desktop")
 
-/* help location */
-#define GPM_HOMEPAGE_URL	 	"http://www.gnome.org/projects/gnome-power-manager/"
-#define GPM_BUGZILLA_URL		"http://bugzilla.gnome.org/buglist.cgi?product=gnome-power-manager"
-#define GPM_FAQ_URL			"http://live.gnome.org/GnomePowerManager/Faq"
-
 /* change general/installed_schema whenever adding or moving keys */
-#define GPM_SETTINGS_SCHEMA_ID				3
 #define GPM_SETTINGS_SCHEMA				"org.gnome.power-manager"
+#define GSD_SETTINGS_SCHEMA				"org.gnome.settings-daemon.plugins.power"
 
 /* actions */
-#define GPM_SETTINGS_ACTION_CRITICAL_UPS		"action-critical-ups"
-#define GPM_SETTINGS_ACTION_CRITICAL_BATT		"action-critical-battery"
-#define GPM_SETTINGS_ACTION_LOW_UPS			"action-low-ups"
-#define GPM_SETTINGS_ACTION_SLEEP_TYPE_AC		"action-sleep-type-ac"
-#define GPM_SETTINGS_ACTION_SLEEP_TYPE_BATT		"action-sleep-type-battery"
-#define GPM_SETTINGS_SLEEP_WHEN_CLOSED			"event-when-closed-battery"
+#define GSD_SETTINGS_ACTION_CRITICAL_BATT		"critical-battery-action"
+#define GSD_SETTINGS_ACTION_SLEEP_TYPE_AC		"sleep-inactive-ac-type"
+#define GSD_SETTINGS_ACTION_SLEEP_TYPE_BATT		"sleep-inactive-battery-type"
 
 /* backlight stuff */
 #define GPM_SETTINGS_BACKLIGHT_ENABLE			"backlight-enable"
 #define GPM_SETTINGS_BACKLIGHT_BATTERY_REDUCE		"backlight-battery-reduce"
-#define GPM_SETTINGS_DPMS_METHOD_AC			"dpms-method-ac"
-#define GPM_SETTINGS_DPMS_METHOD_BATT			"dpms-method-battery"
-#define GPM_SETTINGS_IDLE_BRIGHTNESS			"idle-brightness"
-#define GPM_SETTINGS_IDLE_DIM_AC			"idle-dim-ac"
-#define GPM_SETTINGS_IDLE_DIM_BATT			"idle-dim-battery"
-#define GPM_SETTINGS_IDLE_DIM_TIME			"idle-dim-time"
+#define GSD_SETTINGS_IDLE_BRIGHTNESS			"idle-brightness"
+#define GSD_SETTINGS_IDLE_DIM_AC			"idle-dim-ac"
+#define GSD_SETTINGS_IDLE_DIM_BATT			"idle-dim-battery"
+#define GSD_SETTINGS_IDLE_DIM_TIME			"idle-dim-time"
 #define GPM_SETTINGS_BRIGHTNESS_AC			"brightness-ac"
 #define GPM_SETTINGS_BRIGHTNESS_DIM_BATT		"brightness-dim-battery"
 
 /* buttons */
-#define GPM_SETTINGS_BUTTON_LID_AC			"button-lid-ac"
-#define GPM_SETTINGS_BUTTON_LID_BATT			"button-lid-battery"
-#define GPM_SETTINGS_BUTTON_SUSPEND			"button-suspend"
-#define GPM_SETTINGS_BUTTON_HIBERNATE			"button-hibernate"
-#define GPM_SETTINGS_BUTTON_POWER			"button-power"
+#define GSD_SETTINGS_BUTTON_LID_AC			"lid-close-ac-action"
+#define GSD_SETTINGS_BUTTON_LID_BATT			"lid-close-battery-action"
+#define GSD_SETTINGS_BUTTON_SUSPEND			"button-suspend"
+#define GSD_SETTINGS_BUTTON_HIBERNATE			"button-hibernate"
+#define GSD_SETTINGS_BUTTON_POWER			"button-power"
 
 /* general */
-#define GPM_SETTINGS_SCHEMA_VERSION			"schema-version"
 #define GPM_SETTINGS_USE_TIME_POLICY			"use-time-for-policy"
-#define GPM_SETTINGS_USE_PROFILE_TIME			"use-profile-time"
-#define GPM_SETTINGS_NETWORKMANAGER_SLEEP		"network-sleep"
-#define GPM_SETTINGS_IDLE_CHECK_CPU			"check-type-cpu"
 
 /* lock */
 #define GPM_SETTINGS_LOCK_USE_SCREENSAVER		"lock-use-screensaver"
@@ -112,12 +98,12 @@ G_BEGIN_DECLS
 #define GPM_SETTINGS_TIME_ACTION			"time-action"
 
 /* timeout */
-#define GPM_SETTINGS_SLEEP_COMPUTER_AC			"sleep-computer-ac"
-#define GPM_SETTINGS_SLEEP_COMPUTER_BATT		"sleep-computer-battery"
-#define GPM_SETTINGS_SLEEP_COMPUTER_UPS			"sleep-computer-ups"
-#define GPM_SETTINGS_SLEEP_DISPLAY_AC			"sleep-display-ac"
-#define GPM_SETTINGS_SLEEP_DISPLAY_BATT			"sleep-display-battery"
-#define GPM_SETTINGS_SLEEP_DISPLAY_UPS			"sleep-display-ups"
+#define GSD_SETTINGS_SLEEP_COMPUTER_AC			"sleep-inactive-ac-timeout"
+#define GSD_SETTINGS_SLEEP_COMPUTER_BATT		"sleep-inactive-battery-timeout"
+#define GSD_SETTINGS_SLEEP_COMPUTER_AC_EN			"sleep-inactive-ac"
+#define GSD_SETTINGS_SLEEP_COMPUTER_BATT_EN		"sleep-inactive-battery"
+#define GSD_SETTINGS_SLEEP_DISPLAY_AC			"sleep-display-ac"
+#define GSD_SETTINGS_SLEEP_DISPLAY_BATT			"sleep-display-battery"
 
 /* ui */
 #define GPM_SETTINGS_ICON_POLICY			"icon-policy"
