@@ -27,17 +27,15 @@
 #include <glib/gi18n.h>
 
 #include <gtk/gtk.h>
-#include <dbus/dbus-glib.h>
 #include <gconf/gconf-client.h>
 #include <libupower-glib/upower.h>
 
-#include "egg-debug.h"
-
 #include "gpm-array-float.h"
 #include "gpm-common.h"
 #include "gpm-stock-icons.h"
 #include "gpm-upower.h"
 #include "gpm-graph-widget.h"
+#include "gpm-debug.h"
 
 static GtkBuilder *builder = NULL;
 static GtkListStore *list_store_info = NULL;
@@ -776,7 +774,6 @@ gpm_stats_update_info_data (UpDevice *device)
 		      "has-statistics", &has_statistics,
 		      NULL);
 
-
 	notebook = GTK_NOTEBOOK (gtk_builder_get_object (builder, "notebook1"));
 
 	/* show info page */
@@ -1153,7 +1150,7 @@ gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gpointer use
 		g_settings_set_string (settings, GPM_SETTINGS_INFO_LAST_DEVICE, current_device);
 
 		/* show transaction_id */
-		egg_debug ("selected row is: %s", current_device);
+		g_debug ("selected row is: %s", current_device);
 
 		/* is special device */
 		if (g_strcmp0 (current_device, "wakeups") == 0) {
@@ -1166,7 +1163,7 @@ gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gpointer use
 		}
 
 	} else {
-		egg_debug ("no row selected");
+		g_debug ("no row selected");
 	}
 }
 
@@ -1217,7 +1214,7 @@ gpm_stats_device_added_cb (UpClient *client, UpDevice *device, gpointer user_dat
 {
 	const gchar *object_path;
 	object_path = up_device_get_object_path (device);
-	egg_debug ("added:     %s", object_path);
+	g_debug ("added:     %s", object_path);
 	gpm_stats_add_device (device);
 }
 
@@ -1231,7 +1228,7 @@ gpm_stats_device_changed_cb (UpClient *client, UpDevice *device, gpointer user_d
 	object_path = up_device_get_object_path (device);
 	if (object_path == NULL || current_device == NULL)
 		return;
-	egg_debug ("changed:   %s", object_path);
+	g_debug ("changed:   %s", object_path);
 	if (g_strcmp0 (current_device, object_path) == 0)
 		gpm_stats_update_info_data (device);
 }
@@ -1248,7 +1245,7 @@ gpm_stats_device_removed_cb (UpClient *client, UpDevice *device, gpointer user_d
 	gboolean ret;
 
 	object_path = up_device_get_object_path (device);
-	egg_debug ("removed:   %s", object_path);
+	g_debug ("removed:   %s", object_path);
 	if (g_strcmp0 (current_device, object_path) == 0) {
 		gtk_list_store_clear (list_store_info);
 	}
@@ -1275,7 +1272,7 @@ gpm_stats_history_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	gchar *value;
 	const gchar *axis_x = NULL;
 	const gchar *axis_y = NULL;
-	value = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
+	value = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (widget));
 	if (g_strcmp0 (value, GPM_HISTORY_RATE_TEXT) == 0) {
 		history_type = GPM_HISTORY_RATE_VALUE;
 		/* TRANSLATORS: this is the X axis on the graph */
@@ -1326,7 +1323,7 @@ gpm_stats_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	gchar *value;
 	const gchar *axis_x = NULL;
 	const gchar *axis_y = NULL;
-	value = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
+	value = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (widget));
 	if (g_strcmp0 (value, GPM_STATS_CHARGE_DATA_TEXT) == 0) {
 		stats_type = GPM_STATS_CHARGE_DATA_VALUE;
 		/* TRANSLATORS: this is the X axis on the graph for the whole battery device */
@@ -1375,7 +1372,7 @@ static void
 gpm_stats_range_combo_changed (GtkWidget *widget, gpointer data)
 {
 	gchar *value;
-	value = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
+	value = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (widget));
 	if (g_strcmp0 (value, GPM_HISTORY_MINUTE_TEXT) == 0)
 		history_time = GPM_HISTORY_MINUTE_VALUE;
 	else if (g_strcmp0 (value, GPM_HISTORY_HOUR_TEXT) == 0)
@@ -1448,33 +1445,14 @@ gpm_stats_points_checkbox_stats_cb (GtkWidget *widget, gpointer data)
 	gpm_stats_button_update_ui ();
 }
 
-/**
- * gpm_stats_set_combo_simple_text:
- **/
-static void
-gpm_stats_set_combo_simple_text (GtkWidget *combo_box)
-{
-	GtkCellRenderer *cell;
-	GtkListStore *store;
-
-	store = gtk_list_store_new (1, G_TYPE_STRING);
-	gtk_combo_box_set_model (GTK_COMBO_BOX (combo_box), GTK_TREE_MODEL (store));
-	g_object_unref (store);
-
-	cell = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), cell, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), cell,
-					"text", 0,
-					NULL);
-}
-
 /**
  * gpm_stats_highlight_device:
  **/
-static void
+static gboolean
 gpm_stats_highlight_device (const gchar *object_path)
 {
 	gboolean ret;
+	gboolean found = FALSE;
 	gchar *id = NULL;
 	gchar *path_str;
 	guint i;
@@ -1483,12 +1461,14 @@ gpm_stats_highlight_device (const gchar *object_path)
 	GtkWidget *widget;
 
 	/* check valid */
-	if (!g_str_has_prefix (object_path, "/"))
-		return;
+	if (!g_str_has_prefix (object_path, "/") &&
+	    g_strcmp0 (object_path, "wakeups") != 0) {
+		goto out;
+	}
 
 	/* we have to reuse the treeview data as it may be sorted */
 	ret = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (list_store_devices), &iter);
-	for (i=0; ret; i++) {
+	for (i=0; ret && !found; i++) {
 		gtk_tree_model_get (GTK_TREE_MODEL (list_store_devices), &iter,
 				    GPM_DEVICES_COLUMN_ID, &id,
 				    -1);
@@ -1499,10 +1479,13 @@ gpm_stats_highlight_device (const gchar *object_path)
 			gtk_tree_view_set_cursor_on_cell (GTK_TREE_VIEW (widget), path, NULL, NULL, FALSE);
 			g_free (path_str);
 			gtk_tree_path_free (path);
+			found = TRUE;
 		}
 		g_free (id);
 		ret = gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store_devices), &iter);
 	}
+out:
+	return found;
 }
 
 /**
@@ -1511,7 +1494,7 @@ gpm_stats_highlight_device (const gchar *object_path)
 static gboolean
 gpm_stats_delete_event_cb (GtkWidget *widget, GdkEvent *event, GtkApplication *application)
 {
-	gtk_application_quit (application);
+	g_application_release (G_APPLICATION (application));
 	return FALSE;
 }
 
@@ -1521,32 +1504,24 @@ gpm_stats_delete_event_cb (GtkWidget *widget, GdkEvent *event, GtkApplication *a
 static void
 gpm_stats_button_close_cb (GtkWidget *widget, GtkApplication *application)
 {
-	gtk_application_quit (application);
+	g_application_release (G_APPLICATION (application));
 }
 
 /**
- * main:
+ * gpm_stats_commandline_cb:
  **/
-int
-main (int argc, char *argv[])
+static int
+gpm_stats_commandline_cb (GApplication *application,
+			  GApplicationCommandLine *cmdline,
+			  gpointer user_data)
 {
-	gboolean verbose = FALSE;
-	GOptionContext *context;
-	GtkBox *box;
-	GtkWidget *widget;
-	GtkTreeSelection *selection;
-	GtkApplication *application;
 	gboolean ret;
-	UpClient *client;
-	GPtrArray *devices;
-	UpDevice *device;
-	UpDeviceKind kind;
-	guint i, j;
-	gint page;
-	gboolean checked;
-	gchar *last_device = NULL;
-	guint retval;
-	GError *error = NULL;
+	gboolean verbose = FALSE;
+	gchar **argv;
+	gchar *last_device =  NULL;
+	gint argc;
+	GOptionContext *context;
+	GtkWindow *window;
 
 	const GOptionEntry options[] = {
 		{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
@@ -1558,42 +1533,66 @@ main (int argc, char *argv[])
 		{ NULL}
 	};
 
-	setlocale (LC_ALL, "");
-
-	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-
-	if (! g_thread_supported ())
-		g_thread_init (NULL);
-	dbus_g_thread_init ();
-	g_type_init ();
+	/* get arguments */
+	argv = g_application_command_line_get_arguments (cmdline, &argc);
 
 	context = g_option_context_new (NULL);
 	/* TRANSLATORS: the program name */
 	g_option_context_set_summary (context, _("Power Statistics"));
 	g_option_context_add_main_entries (context, options, NULL);
-	g_option_context_parse (context, &argc, &argv, NULL);
+	g_option_context_add_group (context, gpm_debug_get_option_group ());
+	ret = g_option_context_parse (context, &argc, &argv, NULL);
+	if (!ret)
+		goto out;
+
+	/* get from GSettings if we never specified on the command line */
+	if (last_device == NULL)
+		last_device = g_settings_get_string (settings, GPM_SETTINGS_INFO_LAST_DEVICE);
+
+	/* set the correct focus on the last device */
+	if (last_device != NULL) {
+		ret = gpm_stats_highlight_device (last_device);
+		if (!ret)
+			g_warning ("failed to select");
+		g_free (last_device);
+	}
+
+	/* make sure the window is raised */
+	window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_stats"));
+	gtk_window_present (window);
+out:
+	g_strfreev (argv);
 	g_option_context_free (context);
+	return ret;
+}
 
-	egg_debug_init (verbose);
-	gtk_init (&argc, &argv);
-
-	/* are we already activated? */
-	application = gtk_application_new ("org.gnome.PowerManager.Statistics", &argc, &argv);
-
-	/* add application specific icons to search path */
-	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
-                                           GPM_DATA G_DIR_SEPARATOR_S "icons");
-
-	/* get data from gconf */
-	settings = g_settings_new (GPM_SETTINGS_SCHEMA);
+/**
+ * gpm_stats_startup_cb:
+ **/
+static void
+gpm_stats_startup_cb (GApplication *application,
+		      gpointer user_data)
+{
+	GtkBox *box;
+	GtkWidget *widget;
+	GtkWindow *window;
+	GtkTreeSelection *selection;
+	gboolean ret;
+	UpClient *client;
+	GPtrArray *devices;
+	UpDevice *device;
+	UpDeviceKind kind;
+	guint i, j;
+	gint page;
+	gboolean checked;
+	guint retval;
+	GError *error = NULL;
 
 	/* get UI */
 	builder = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (builder, GPM_DATA "/gpm-statistics.ui", &error);
 	if (retval == 0) {
-		egg_warning ("failed to load ui: %s", error->message);
+		g_warning ("failed to load ui: %s", error->message);
 		g_error_free (error);
 	}
 
@@ -1611,18 +1610,20 @@ main (int argc, char *argv[])
 	gtk_widget_set_size_request (graph_statistics, 400, 250);
 	gtk_widget_show (graph_statistics);
 
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
-	gtk_application_add_window (application, GTK_WINDOW (widget));
-	gtk_window_set_default_size (GTK_WINDOW(widget), 800, 500);
+	window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_stats"));
+	gtk_window_set_application (window, GTK_APPLICATION (application));
+	gtk_window_set_default_size (window, 800, 500);
+	gtk_window_set_application (window, GTK_APPLICATION (application));
 	gtk_window_set_default_icon_name (GPM_STOCK_APP_ICON);
 
 	/* Get the main window quit */
-	g_signal_connect (widget, "delete-event",
+	g_signal_connect (window, "delete-event",
 			  G_CALLBACK (gpm_stats_delete_event_cb), application);
 
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
+        widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_button_close_cb), application);
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
 	gtk_widget_grab_default (widget);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
@@ -1708,11 +1709,10 @@ main (int argc, char *argv[])
 		stats_type = GPM_STATS_CHARGE_DATA_VALUE;
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_history_type"));
-	gpm_stats_set_combo_simple_text (widget);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_RATE_TEXT);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_CHARGE_TEXT);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_TIME_FULL_TEXT);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_TIME_EMPTY_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_RATE_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_CHARGE_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_TIME_FULL_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_TIME_EMPTY_TEXT);
 	if (g_strcmp0 (history_type, GPM_HISTORY_RATE_VALUE) == 0)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 	else
@@ -1721,11 +1721,10 @@ main (int argc, char *argv[])
 			  G_CALLBACK (gpm_stats_history_type_combo_changed_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_stats_type"));
-	gpm_stats_set_combo_simple_text (widget);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_STATS_CHARGE_DATA_TEXT);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_STATS_CHARGE_ACCURACY_TEXT);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_STATS_DISCHARGE_DATA_TEXT);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_STATS_DISCHARGE_ACCURACY_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_CHARGE_DATA_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_CHARGE_ACCURACY_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_DISCHARGE_DATA_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_DISCHARGE_ACCURACY_TEXT);
 	if (g_strcmp0 (stats_type, GPM_STATS_CHARGE_DATA_VALUE) == 0)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 	else if (g_strcmp0 (stats_type, GPM_STATS_CHARGE_DATA_VALUE) == 0)
@@ -1740,12 +1739,11 @@ main (int argc, char *argv[])
 			  G_CALLBACK (gpm_stats_type_combo_changed_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_history_time"));
-	gpm_stats_set_combo_simple_text (widget);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_MINUTE_TEXT);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_HOUR_TEXT);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_HOURS_TEXT);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_DAY_TEXT);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_WEEK_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_MINUTE_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_HOUR_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_HOURS_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_DAY_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_WEEK_TEXT);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 1);
 	if (history_time == GPM_HISTORY_MINUTE_VALUE)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
@@ -1756,7 +1754,6 @@ main (int argc, char *argv[])
 	g_signal_connect (G_OBJECT (widget), "changed",
 			  G_CALLBACK (gpm_stats_range_combo_changed), NULL);
 
-
 	wakeups = up_wakeups_new ();
 	g_signal_connect (wakeups, "data-changed", G_CALLBACK (gpm_stats_data_changed_cb), NULL);
 
@@ -1787,9 +1784,6 @@ main (int argc, char *argv[])
 		current_device = g_strdup (up_device_get_object_path (device));
 	}
 
-	if (last_device == NULL)
-		last_device = g_settings_get_string (settings, GPM_SETTINGS_INFO_LAST_DEVICE);
-
 	/* has capability to measure wakeups */
 	ret = up_wakeups_get_has_capability (wakeups);
 	if (ret) {
@@ -1805,10 +1799,6 @@ main (int argc, char *argv[])
 		g_object_unref (icon);
 	}
 
-	/* set the correct focus on the last device */
-	if (last_device != NULL)
-		gpm_stats_highlight_device (last_device);
-
 	g_ptr_array_unref (devices);
 
 	/* set axis */
@@ -1819,17 +1809,50 @@ main (int argc, char *argv[])
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
 	gtk_widget_show (widget);
+out:
+	g_object_unref (client);
+}
+
+/**
+ * main:
+ **/
+int
+main (int argc, char *argv[])
+{
+	GtkApplication *application;
+	int status = 0;
+
+	setlocale (LC_ALL, "");
+
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
+	if (! g_thread_supported ())
+		g_thread_init (NULL);
+	g_type_init ();
+
+	gtk_init (&argc, &argv);
+
+	/* get data from gconf */
+	settings = g_settings_new (GPM_SETTINGS_SCHEMA);
+
+	/* are we already activated? */
+	application = gtk_application_new ("org.gnome.PowerManager.Statistics",
+					   G_APPLICATION_HANDLES_COMMAND_LINE);
+	g_signal_connect (application, "startup",
+			  G_CALLBACK (gpm_stats_startup_cb), NULL);
+	g_signal_connect (application, "command-line",
+			  G_CALLBACK (gpm_stats_commandline_cb), NULL);
+
+	/* add application specific icons to search path */
+	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
+                                           GPM_DATA G_DIR_SEPARATOR_S "icons");
 
 	/* run */
-	gtk_application_run (application);
+	status = g_application_run (G_APPLICATION (application), argc, argv);
 
-out:
 	g_object_unref (settings);
-	g_object_unref (client);
-	g_object_unref (wakeups);
-	g_object_unref (builder);
-	g_object_unref (list_store_info);
 	g_object_unref (application);
-	g_free (last_device);
-	return 0;
+	return status;
 }
